#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-tujSmYb4OMKf9OZEBOZZG
key:                  coinbase-pro-0.9.3.2-tujSmYb4OMKf9OZEBOZZG
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  f3b850461a36ff7a36173d2c00cbd12b
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-tujSmYb4OMKf9OZEBOZZG
depends:
    HsOpenSSL-0.11.7.10-KkWOBA8bpmBK42QZeYTnB5
    aeson-2.2.2.0-DD8qksC39c7IadfiHLVY3V
    aeson-casing-0.2.0.0-9rFFny1FtkZDhjOlqzfwWU
    async-2.2.6-BOzBj9OU2RsBdXVaxuDTSw base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-K2RP6l7MNbc1iRxw92DkbX exceptions-0.10.7
    http-api-data-0.6.1-KlHJLQBDkAr6EHCmGfuZmw
    http-client-0.7.19-4FCJ2m94wUmJsssaVohngD
    http-client-tls-0.3.6.4-K9pa9aqIB7M16aJexgoa6z
    http-streams-0.8.9.9-8a6JYAFiXRuIJQvpCNVh5J
    http-types-0.12.4-2JHh5Qo0ssgCXdBZ0yuSfo
    io-streams-1.5.2.2-CPyOtMPtkgoDqc3szFWdzn
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-4Rsy3d52Nm21mbavP5v2o
    servant-0.20.3.0-3IUKiEKgWjNKQrbUUjsv56
    servant-client-0.20.3.0-IzR6UPxDKBe5OyvgQbPJk1
    servant-client-core-0.20.3.0-Cs8USperzYJLecqqpRqzS1
    tasty-1.5.4-IL2dKu3GamJ8dAyKzmzJIp
    tasty-hunit-0.10.2-Gfrl2qmM0rHENX9WQOKRff text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-IpzgTPunPAnKp1dl4sW0iZ
    unordered-containers-0.2.21-1uyZH24PObnIj7baK8tBEp
    uuid-1.3.16.1-7PYZMZ1xYXRJIRW62n80Y6
    vector-0.13.2.0-5a59Ladt6HH20irTaXAFu7
    websockets-0.12.7.3-Kfmo7flFoDf1FHWYGXCLBs
    wuss-2.0.1.7-B1lNzWkVZLXKNZnmsDuoTg

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

